#!/bin/sh
# @(#) Gigapxy setup/cleanup script

GPX_HOME=/opt/gigapxy
case `uname -s` in
    FreeBSD)    PKILL=/bin/pkill; PGREP=/bin/pgrep ;;
    Linux)      PKILL=/usr/bin/pkill; PGREP=/usr/bin/pgrep ;;
esac

: ${EUID:=`id -u`}


lnx_setup()
{
    if ! grep -q gigapxy /etc/passwd; then
        if [ ${EUID} = 0 ]; then
            /usr/sbin/useradd -r -U -m -d ${GPX_HOME} -s /sbin/nologin \
                -c 'gigapxy runtime user' gigapxy
            mkdir -p /var/log/gigapxy && chown gigapxy:gigapxy /var/log/gigapxy
        else
            echo >&2 "$0: cannot create user w/o root privileges."
        fi
    fi
}


lnx_cleanup()
{
    if ${PGREP} gws; then ${PKILL} gws; fi
    if ${PGREP} gng; then ${PKILL} gng; fi

# NB: user and its home stay behind (better safe than sorry).
#
    #if grep -q gigapxy /etc/passwd; then
    #    if [ ${EUID} -eq 0 ]; then
    #        /usr/sbin/deluser --remove-home gigapxy
    #        rm -fr ${GPX_HOME}
    #    else
    #        echo >&2 "$0: remove create user w/o root privileges."
    #    fi
    #fi
}


fbsd_setup()
{
    if ! grep -q gigapxy /etc/passwd; then
        if [ ${EUID} = 0 ]; then
            /usr/sbin/pw useradd gigapxy -d ${GPX_HOME} -m -L daemon
            mkdir -p /var/log/gigapxy && chown gigapxy:gigapxy /var/log/gigapxy
        else
            echo >&2 "$0: cannot delete user w/o root privileges."
        fi
    fi
}


fbsd_cleanup()
{
    if ${PGREP} gws; then ${PKILL} gws; fi
    if ${PGREP} gng; then ${PKILL} gng; fi

# NB: user and its home stay behind (better safe than sorry).
#
    #if grep -q gigapxy /etc/passwd; then
    #    if [ ${EUID} = 0 ]; then
    #        /usr/sbin/pw userdel gigapxy -r
    #    else
    #        echo >&2 "$0: cannot delete user w/o root privileges."
    #    fi
    #fi
}


do_setup()
{
    case `uname -s` in
        FreeBSD) fbsd_setup ;;
        Linux)   lnx_setup ;;
    esac
}


do_cleanup()
{
    case `uname -s` in
        FreeBSD) fbsd_cleanup ;;
        Linux)   lnx_cleanup ;;
    esac
}


## Main
##

if [ $# -lt 1 ]; then
    echo >&2 "Usage: $0 setup|cleanup"
    exit 1
fi

mode=${1:?}
case $mode in
    setup|SETUP)        do_setup ;;
    cleanup|CLEANUP)    do_cleanup ;;
    *) echo >&2 "$0: unrecognized mode: $1"; exit 1 ;;
esac

# __EOF__

